@@ -6,6 +6,7 @@ AnyEvent::IO - the DBI of asynchronous I/O implementations
 
    use AnyEvent::IO;
 
+   # load /etc/passwd, call clalback with the file data when done.
    aio_load "/etc/passwd", sub {
       my ($data) = @_
          or return AE::log error => "/etc/passwd: $!";
@@ -13,21 +14,26 @@ AnyEvent::IO - the DBI of asynchronous I/O implementations
       warn "/etc/passwd contains ", ($data =~ y/://) , " colons.\n";
    };
 
+   # the rest of the SYNOPSIS does the same, but with individual I/O calls
+
    # also import O_XXX flags
    use AnyEvent::IO qw(:DEFAULT :flags);
 
    my $filedata = AE::cv;
 
+   # first open the file
    aio_open "/etc/passwd", O_RDONLY, 0, sub {
       my ($fh) = @_
          or return AE::log error => "/etc/passwd: $!";
 
+      # now stat the file to get the size
       aio_stat $fh, sub {
          @_
             or return AE::log error => "/etc/passwd: $!";
 
          my $size = -s _;
 
+         # now read all the file data
          aio_read $fh, $size, sub {
             my ($data) = @_
                or return AE::log error => "/etc/passwd: $!";
@@ -48,14 +54,14 @@ AnyEvent::IO - the DBI of asynchronous I/O implementations
 =head1 DESCRIPTION
 
 This module provides functions that do I/O in an asynchronous fashion. It
-is to to I/O the same as L<AnyEvent> is to event libraries - it only
+is to I/O the same as L<AnyEvent> is to event libraries - it only
 I<interfaces> to other implementations or to a portable pure-perl
-implementation (that does not, however, do asynchronous I/O).
+implementation (which does not, however, do asynchronous I/O).
 
-The only such implementation that is supported (or even known to the
-author) is L<IO::AIO>, which is used automatically when it can be
-loaded. If it is not available, L<AnyEvent::IO> falls back to its
-(synchronous) pure-perl implementation.
+The only other implementation that is supported (or even known to
+the author) is L<IO::AIO>, which is used automatically when it can
+be loaded. If it is not available, L<AnyEvent::IO> falls back to its
+synchronous pure-perl implementation.
 
 Unlike L<AnyEvent>, which model to use is currently decided at module load
 time, not at first use. Future releases might change this.
@@ -65,7 +71,7 @@ time, not at first use. Future releases might change this.
 While disk I/O often seems "instant" compared to, say, socket I/O, there
 are many situations where your program can block for extended time periods
 when doing disk I/O. For example, you access a disk on an NFS server and
-it is gone - can take ages to respond again, if ever.  OR your system is
+it is gone - can take ages to respond again, if ever. Or your system is
 extremely busy because it creates or restores a backup - reading data from
 disk can then take seconds. Or you use Linux, which for so many years has
 a close-to-broken VM/IO subsystem that can often induce minutes or more of
@@ -198,6 +204,8 @@ otherwise rely on the current umask) results in undefined behaviour -
 likewise changing anything else that would change the outcome, such as
 your effective user or group ID.
 
+=head2 CALLBACKS MIGHT BE CALLED BEFORE FUNCTION RETURNS TO CALLER
+
 Unlike other functions in the AnyEvent module family, these functions
 I<may> call your callback instantly, before returning. This should not be
 a real problem, as these functions never return anything useful.
